@@ -1,7 +1,7 @@
 from collections import defaultdict
 from dataclasses import dataclass, field
 
-from src.block import Block
+from gandalf.block import Block
 
 
 @dataclass
